
.. _mapper_config_toplevel:

====================
Mapper Configuration
====================

This section describes a variety of configurational patterns that are usable
with mappers. It assumes you've worked through :ref:`ormtutorial_toplevel` and
know how to construct and use rudimentary mappers and relationships.


.. toctree::
    :maxdepth: 2

    mapping_styles
    scalar_mapping
    inheritance
    nonstandard_mappings
    versioning
    mapping_api
